==> gnucash_2.4.0.orig.tar.bz2: gnucash-2.4.0/src/gnome/window-autoclear.h <==
/********************************************************************\
 * window-autoclear.h -- the autoclear window                       *
 * Copyright (C) 2010 Cristian KLEIN                                *
 *                                                                  *
 * This program is free software; you can redistribute it and/or    *
 * modify it under the terms of the GNU General Public License as   *
 * published by the Free Software Foundation; either version 2 of   *
 * the License, or (at your option) any later version.              *
 *                                                                  *
 * This program is distributed in the hope that it will be useful,  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
 * GNU General Public License for more details.                     *
 *                                                                  *
 * You should have received a copy of the GNU General Public License*
 * along with this program; if not, contact:                        *
 *                                                                  *
 * Free Software Foundation           Voice:  +1-617-542-5942       *
 * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
 * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
\********************************************************************/

#ifndef WINDOW_AUTOCLEAR_H
#define WINDOW_AUTOCLEAR_H

typedef struct _AutoClearWindow AutoClearWindow;

AutoClearWindow *autoClearWindow (gncUIWidget parent, Account *account);
void gnc_ui_autoclear_window_raise(AutoClearWindow * autoClearData);

#endif

==> gnucash_2.6.12.orig.tar.bz2: gnucash-2.6.12/src/gnome/window-autoclear.h <==
/********************************************************************\
 * window-autoclear.h -- the autoclear window                       *
 * Copyright (C) 2010 Cristian KLEIN                                *
 *                                                                  *
 * This program is free software; you can redistribute it and/or    *
 * modify it under the terms of the GNU General Public License as   *
 * published by the Free Software Foundation; either version 2 of   *
 * the License, or (at your option) any later version.              *
 *                                                                  *
 * This program is distributed in the hope that it will be useful,  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
 * GNU General Public License for more details.                     *
 *                                                                  *
 * You should have received a copy of the GNU General Public License*
 * along with this program; if not, contact:                        *
 *                                                                  *
 * Free Software Foundation           Voice:  +1-617-542-5942       *
 * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
 * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
\********************************************************************/

#ifndef WINDOW_AUTOCLEAR_H
#define WINDOW_AUTOCLEAR_H

typedef struct _AutoClearWindow AutoClearWindow;

AutoClearWindow *autoClearWindow (GtkWidget *parent, Account *account);
void gnc_ui_autoclear_window_raise(AutoClearWindow * autoClearData);

#endif
